pubsubpb

package
v1.50.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 4, 2025 License: Apache-2.0 Imports: 2 Imported by: 37

Documentation

Overview

Package pubsub aliases all exported identifiers in package "cloud.google.com/go/pubsub/v2/apiv1/pubsubpb".

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb.

Index

Constants

const (
	BigQueryConfig_ACTIVE                                                        = src.BigQueryConfig_ACTIVE
	BigQueryConfig_IN_TRANSIT_LOCATION_RESTRICTION                               = src.BigQueryConfig_IN_TRANSIT_LOCATION_RESTRICTION
	BigQueryConfig_NOT_FOUND                                                     = src.BigQueryConfig_NOT_FOUND
	BigQueryConfig_PERMISSION_DENIED                                             = src.BigQueryConfig_PERMISSION_DENIED
	BigQueryConfig_SCHEMA_MISMATCH                                               = src.BigQueryConfig_SCHEMA_MISMATCH
	BigQueryConfig_STATE_UNSPECIFIED                                             = src.BigQueryConfig_STATE_UNSPECIFIED
	CloudStorageConfig_ACTIVE                                                    = src.CloudStorageConfig_ACTIVE
	CloudStorageConfig_IN_TRANSIT_LOCATION_RESTRICTION                           = src.CloudStorageConfig_IN_TRANSIT_LOCATION_RESTRICTION
	CloudStorageConfig_NOT_FOUND                                                 = src.CloudStorageConfig_NOT_FOUND
	CloudStorageConfig_PERMISSION_DENIED                                         = src.CloudStorageConfig_PERMISSION_DENIED
	CloudStorageConfig_SCHEMA_MISMATCH                                           = src.CloudStorageConfig_SCHEMA_MISMATCH
	CloudStorageConfig_STATE_UNSPECIFIED                                         = src.CloudStorageConfig_STATE_UNSPECIFIED
	Encoding_BINARY                                                              = src.Encoding_BINARY
	Encoding_ENCODING_UNSPECIFIED                                                = src.Encoding_ENCODING_UNSPECIFIED
	Encoding_JSON                                                                = src.Encoding_JSON
	IngestionDataSourceSettings_AwsKinesis_ACTIVE                                = src.IngestionDataSourceSettings_AwsKinesis_ACTIVE
	IngestionDataSourceSettings_AwsKinesis_CONSUMER_NOT_FOUND                    = src.IngestionDataSourceSettings_AwsKinesis_CONSUMER_NOT_FOUND
	IngestionDataSourceSettings_AwsKinesis_KINESIS_PERMISSION_DENIED             = src.IngestionDataSourceSettings_AwsKinesis_KINESIS_PERMISSION_DENIED
	IngestionDataSourceSettings_AwsKinesis_PUBLISH_PERMISSION_DENIED             = src.IngestionDataSourceSettings_AwsKinesis_PUBLISH_PERMISSION_DENIED
	IngestionDataSourceSettings_AwsKinesis_STATE_UNSPECIFIED                     = src.IngestionDataSourceSettings_AwsKinesis_STATE_UNSPECIFIED
	IngestionDataSourceSettings_AwsKinesis_STREAM_NOT_FOUND                      = src.IngestionDataSourceSettings_AwsKinesis_STREAM_NOT_FOUND
	IngestionDataSourceSettings_AwsMsk_ACTIVE                                    = src.IngestionDataSourceSettings_AwsMsk_ACTIVE
	IngestionDataSourceSettings_AwsMsk_CLUSTER_NOT_FOUND                         = src.IngestionDataSourceSettings_AwsMsk_CLUSTER_NOT_FOUND
	IngestionDataSourceSettings_AwsMsk_MSK_PERMISSION_DENIED                     = src.IngestionDataSourceSettings_AwsMsk_MSK_PERMISSION_DENIED
	IngestionDataSourceSettings_AwsMsk_PUBLISH_PERMISSION_DENIED                 = src.IngestionDataSourceSettings_AwsMsk_PUBLISH_PERMISSION_DENIED
	IngestionDataSourceSettings_AwsMsk_STATE_UNSPECIFIED                         = src.IngestionDataSourceSettings_AwsMsk_STATE_UNSPECIFIED
	IngestionDataSourceSettings_AwsMsk_TOPIC_NOT_FOUND                           = src.IngestionDataSourceSettings_AwsMsk_TOPIC_NOT_FOUND
	IngestionDataSourceSettings_AzureEventHubs_ACTIVE                            = src.IngestionDataSourceSettings_AzureEventHubs_ACTIVE
	IngestionDataSourceSettings_AzureEventHubs_EVENT_HUBS_PERMISSION_DENIED      = src.IngestionDataSourceSettings_AzureEventHubs_EVENT_HUBS_PERMISSION_DENIED
	IngestionDataSourceSettings_AzureEventHubs_EVENT_HUB_NOT_FOUND               = src.IngestionDataSourceSettings_AzureEventHubs_EVENT_HUB_NOT_FOUND
	IngestionDataSourceSettings_AzureEventHubs_NAMESPACE_NOT_FOUND               = src.IngestionDataSourceSettings_AzureEventHubs_NAMESPACE_NOT_FOUND
	IngestionDataSourceSettings_AzureEventHubs_PUBLISH_PERMISSION_DENIED         = src.IngestionDataSourceSettings_AzureEventHubs_PUBLISH_PERMISSION_DENIED
	IngestionDataSourceSettings_AzureEventHubs_RESOURCE_GROUP_NOT_FOUND          = src.IngestionDataSourceSettings_AzureEventHubs_RESOURCE_GROUP_NOT_FOUND
	IngestionDataSourceSettings_AzureEventHubs_STATE_UNSPECIFIED                 = src.IngestionDataSourceSettings_AzureEventHubs_STATE_UNSPECIFIED
	IngestionDataSourceSettings_AzureEventHubs_SUBSCRIPTION_NOT_FOUND            = src.IngestionDataSourceSettings_AzureEventHubs_SUBSCRIPTION_NOT_FOUND
	IngestionDataSourceSettings_CloudStorage_ACTIVE                              = src.IngestionDataSourceSettings_CloudStorage_ACTIVE
	IngestionDataSourceSettings_CloudStorage_BUCKET_NOT_FOUND                    = src.IngestionDataSourceSettings_CloudStorage_BUCKET_NOT_FOUND
	IngestionDataSourceSettings_CloudStorage_CLOUD_STORAGE_PERMISSION_DENIED     = src.IngestionDataSourceSettings_CloudStorage_CLOUD_STORAGE_PERMISSION_DENIED
	IngestionDataSourceSettings_CloudStorage_PUBLISH_PERMISSION_DENIED           = src.IngestionDataSourceSettings_CloudStorage_PUBLISH_PERMISSION_DENIED
	IngestionDataSourceSettings_CloudStorage_STATE_UNSPECIFIED                   = src.IngestionDataSourceSettings_CloudStorage_STATE_UNSPECIFIED
	IngestionDataSourceSettings_CloudStorage_TOO_MANY_OBJECTS                    = src.IngestionDataSourceSettings_CloudStorage_TOO_MANY_OBJECTS
	IngestionDataSourceSettings_ConfluentCloud_ACTIVE                            = src.IngestionDataSourceSettings_ConfluentCloud_ACTIVE
	IngestionDataSourceSettings_ConfluentCloud_CLUSTER_NOT_FOUND                 = src.IngestionDataSourceSettings_ConfluentCloud_CLUSTER_NOT_FOUND
	IngestionDataSourceSettings_ConfluentCloud_CONFLUENT_CLOUD_PERMISSION_DENIED = src.IngestionDataSourceSettings_ConfluentCloud_CONFLUENT_CLOUD_PERMISSION_DENIED
	IngestionDataSourceSettings_ConfluentCloud_PUBLISH_PERMISSION_DENIED         = src.IngestionDataSourceSettings_ConfluentCloud_PUBLISH_PERMISSION_DENIED
	IngestionDataSourceSettings_ConfluentCloud_STATE_UNSPECIFIED                 = src.IngestionDataSourceSettings_ConfluentCloud_STATE_UNSPECIFIED
	IngestionDataSourceSettings_ConfluentCloud_TOPIC_NOT_FOUND                   = src.IngestionDataSourceSettings_ConfluentCloud_TOPIC_NOT_FOUND
	IngestionDataSourceSettings_ConfluentCloud_UNREACHABLE_BOOTSTRAP_SERVER      = src.IngestionDataSourceSettings_ConfluentCloud_UNREACHABLE_BOOTSTRAP_SERVER
	PlatformLogsSettings_DEBUG                                                   = src.PlatformLogsSettings_DEBUG
	PlatformLogsSettings_DISABLED                                                = src.PlatformLogsSettings_DISABLED
	PlatformLogsSettings_ERROR                                                   = src.PlatformLogsSettings_ERROR
	PlatformLogsSettings_INFO                                                    = src.PlatformLogsSettings_INFO
	PlatformLogsSettings_SEVERITY_UNSPECIFIED                                    = src.PlatformLogsSettings_SEVERITY_UNSPECIFIED
	PlatformLogsSettings_WARNING                                                 = src.PlatformLogsSettings_WARNING
	SchemaView_BASIC                                                             = src.SchemaView_BASIC
	SchemaView_FULL                                                              = src.SchemaView_FULL
	SchemaView_SCHEMA_VIEW_UNSPECIFIED                                           = src.SchemaView_SCHEMA_VIEW_UNSPECIFIED
	Schema_AVRO                                                                  = src.Schema_AVRO
	Schema_PROTOCOL_BUFFER                                                       = src.Schema_PROTOCOL_BUFFER
	Schema_TYPE_UNSPECIFIED                                                      = src.Schema_TYPE_UNSPECIFIED
	Subscription_ACTIVE                                                          = src.Subscription_ACTIVE
	Subscription_RESOURCE_ERROR                                                  = src.Subscription_RESOURCE_ERROR
	Subscription_STATE_UNSPECIFIED                                               = src.Subscription_STATE_UNSPECIFIED
	Topic_ACTIVE                                                                 = src.Topic_ACTIVE
	Topic_INGESTION_RESOURCE_ERROR                                               = src.Topic_INGESTION_RESOURCE_ERROR
	Topic_STATE_UNSPECIFIED                                                      = src.Topic_STATE_UNSPECIFIED
)

Deprecated: Please use consts in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

Variables

var (
	BigQueryConfig_State_name                              = src.BigQueryConfig_State_name
	BigQueryConfig_State_value                             = src.BigQueryConfig_State_value
	CloudStorageConfig_State_name                          = src.CloudStorageConfig_State_name
	CloudStorageConfig_State_value                         = src.CloudStorageConfig_State_value
	Encoding_name                                          = src.Encoding_name
	Encoding_value                                         = src.Encoding_value
	File_google_pubsub_v1_pubsub_proto                     = src.File_google_pubsub_v1_pubsub_proto
	File_google_pubsub_v1_schema_proto                     = src.File_google_pubsub_v1_schema_proto
	IngestionDataSourceSettings_AwsKinesis_State_name      = src.IngestionDataSourceSettings_AwsKinesis_State_name
	IngestionDataSourceSettings_AwsKinesis_State_value     = src.IngestionDataSourceSettings_AwsKinesis_State_value
	IngestionDataSourceSettings_AwsMsk_State_name          = src.IngestionDataSourceSettings_AwsMsk_State_name
	IngestionDataSourceSettings_AwsMsk_State_value         = src.IngestionDataSourceSettings_AwsMsk_State_value
	IngestionDataSourceSettings_AzureEventHubs_State_name  = src.IngestionDataSourceSettings_AzureEventHubs_State_name
	IngestionDataSourceSettings_AzureEventHubs_State_value = src.IngestionDataSourceSettings_AzureEventHubs_State_value
	IngestionDataSourceSettings_CloudStorage_State_name    = src.IngestionDataSourceSettings_CloudStorage_State_name
	IngestionDataSourceSettings_CloudStorage_State_value   = src.IngestionDataSourceSettings_CloudStorage_State_value
	IngestionDataSourceSettings_ConfluentCloud_State_name  = src.IngestionDataSourceSettings_ConfluentCloud_State_name
	IngestionDataSourceSettings_ConfluentCloud_State_value = src.IngestionDataSourceSettings_ConfluentCloud_State_value
	PlatformLogsSettings_Severity_name                     = src.PlatformLogsSettings_Severity_name
	PlatformLogsSettings_Severity_value                    = src.PlatformLogsSettings_Severity_value
	SchemaView_name                                        = src.SchemaView_name
	SchemaView_value                                       = src.SchemaView_value
	Schema_Type_name                                       = src.Schema_Type_name
	Schema_Type_value                                      = src.Schema_Type_value
	Subscription_State_name                                = src.Subscription_State_name
	Subscription_State_value                               = src.Subscription_State_value
	Topic_State_name                                       = src.Topic_State_name
	Topic_State_value                                      = src.Topic_State_value
)

Deprecated: Please use vars in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

Functions

func RegisterPublisherServer deprecated

func RegisterPublisherServer(s *grpc.Server, srv PublisherServer)

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

func RegisterSchemaServiceServer deprecated

func RegisterSchemaServiceServer(s *grpc.Server, srv SchemaServiceServer)

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

func RegisterSubscriberServer deprecated

func RegisterSubscriberServer(s *grpc.Server, srv SubscriberServer)

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

Types

type AcknowledgeRequest deprecated

type AcknowledgeRequest = src.AcknowledgeRequest

Request for the Acknowledge method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type BigQueryConfig deprecated

type BigQueryConfig = src.BigQueryConfig

Configuration for a BigQuery subscription.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type BigQueryConfig_State deprecated

type BigQueryConfig_State = src.BigQueryConfig_State

Possible states for a BigQuery subscription.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CloudStorageConfig deprecated added in v1.31.0

type CloudStorageConfig = src.CloudStorageConfig

Configuration for a Cloud Storage subscription.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CloudStorageConfig_AvroConfig deprecated added in v1.31.0

type CloudStorageConfig_AvroConfig = src.CloudStorageConfig_AvroConfig

Configuration for writing message data in Avro format. Message payloads and metadata will be written to files as an Avro binary.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CloudStorageConfig_AvroConfig_ added in v1.31.0

type CloudStorageConfig_AvroConfig_ = src.CloudStorageConfig_AvroConfig_

type CloudStorageConfig_State deprecated added in v1.31.0

type CloudStorageConfig_State = src.CloudStorageConfig_State

Possible states for a Cloud Storage subscription.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CloudStorageConfig_TextConfig deprecated added in v1.31.0

type CloudStorageConfig_TextConfig = src.CloudStorageConfig_TextConfig

Configuration for writing message data in text format. Message payloads will be written to files as raw text, separated by a newline.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CloudStorageConfig_TextConfig_ added in v1.31.0

type CloudStorageConfig_TextConfig_ = src.CloudStorageConfig_TextConfig_

type CommitSchemaRequest deprecated added in v1.29.0

type CommitSchemaRequest = src.CommitSchemaRequest

Request for CommitSchema method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CreateSchemaRequest deprecated

type CreateSchemaRequest = src.CreateSchemaRequest

Request for the CreateSchema method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type CreateSnapshotRequest deprecated

type CreateSnapshotRequest = src.CreateSnapshotRequest

Request for the `CreateSnapshot` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeadLetterPolicy deprecated

type DeadLetterPolicy = src.DeadLetterPolicy

Dead lettering is done on a best effort basis. The same message might be dead lettered multiple times. If validation on any of the fields fails at subscription creation/updation, the create/update subscription request will fail.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeleteSchemaRequest deprecated

type DeleteSchemaRequest = src.DeleteSchemaRequest

Request for the `DeleteSchema` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeleteSchemaRevisionRequest deprecated added in v1.29.0

type DeleteSchemaRevisionRequest = src.DeleteSchemaRevisionRequest

Request for the `DeleteSchemaRevision` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeleteSnapshotRequest deprecated

type DeleteSnapshotRequest = src.DeleteSnapshotRequest

Request for the `DeleteSnapshot` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeleteSubscriptionRequest deprecated

type DeleteSubscriptionRequest = src.DeleteSubscriptionRequest

Request for the DeleteSubscription method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DeleteTopicRequest deprecated

type DeleteTopicRequest = src.DeleteTopicRequest

Request for the `DeleteTopic` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DetachSubscriptionRequest deprecated

type DetachSubscriptionRequest = src.DetachSubscriptionRequest

Request for the DetachSubscription method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type DetachSubscriptionResponse deprecated

type DetachSubscriptionResponse = src.DetachSubscriptionResponse

Response for the DetachSubscription method. Reserved for future use.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Encoding deprecated

type Encoding = src.Encoding

Possible encoding types for messages.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ExpirationPolicy deprecated

type ExpirationPolicy = src.ExpirationPolicy

A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type GetSchemaRequest deprecated

type GetSchemaRequest = src.GetSchemaRequest

Request for the GetSchema method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type GetSnapshotRequest deprecated

type GetSnapshotRequest = src.GetSnapshotRequest

Request for the GetSnapshot method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type GetSubscriptionRequest deprecated

type GetSubscriptionRequest = src.GetSubscriptionRequest

Request for the GetSubscription method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type GetTopicRequest deprecated

type GetTopicRequest = src.GetTopicRequest

Request for the GetTopic method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings deprecated added in v1.36.0

type IngestionDataSourceSettings = src.IngestionDataSourceSettings

Settings for an ingestion data source on a topic.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AwsKinesis deprecated added in v1.36.0

type IngestionDataSourceSettings_AwsKinesis = src.IngestionDataSourceSettings_AwsKinesis

Ingestion settings for Amazon Kinesis Data Streams.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AwsKinesis_ added in v1.36.0

type IngestionDataSourceSettings_AwsKinesis_ = src.IngestionDataSourceSettings_AwsKinesis_

type IngestionDataSourceSettings_AwsKinesis_State deprecated added in v1.36.0

type IngestionDataSourceSettings_AwsKinesis_State = src.IngestionDataSourceSettings_AwsKinesis_State

Possible states for ingestion from Amazon Kinesis Data Streams.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AwsMsk deprecated added in v1.46.0

type IngestionDataSourceSettings_AwsMsk = src.IngestionDataSourceSettings_AwsMsk

Ingestion settings for Amazon MSK.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AwsMsk_ added in v1.46.0

type IngestionDataSourceSettings_AwsMsk_ = src.IngestionDataSourceSettings_AwsMsk_

type IngestionDataSourceSettings_AwsMsk_State deprecated added in v1.46.0

type IngestionDataSourceSettings_AwsMsk_State = src.IngestionDataSourceSettings_AwsMsk_State

Possible states for managed ingestion from Amazon MSK.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AzureEventHubs deprecated added in v1.46.0

type IngestionDataSourceSettings_AzureEventHubs = src.IngestionDataSourceSettings_AzureEventHubs

Ingestion settings for Azure Event Hubs.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_AzureEventHubs_ added in v1.46.0

type IngestionDataSourceSettings_AzureEventHubs_ = src.IngestionDataSourceSettings_AzureEventHubs_

type IngestionDataSourceSettings_AzureEventHubs_State deprecated added in v1.46.0

type IngestionDataSourceSettings_AzureEventHubs_State = src.IngestionDataSourceSettings_AzureEventHubs_State

Possible states for managed ingestion from Event Hubs.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage deprecated added in v1.44.0

type IngestionDataSourceSettings_CloudStorage = src.IngestionDataSourceSettings_CloudStorage

Ingestion settings for Cloud Storage.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage_ added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_ = src.IngestionDataSourceSettings_CloudStorage_

type IngestionDataSourceSettings_CloudStorage_AvroFormat deprecated added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_AvroFormat = src.IngestionDataSourceSettings_CloudStorage_AvroFormat

Configuration for reading Cloud Storage data in Avro binary format. The bytes of each object will be set to the `data` field of a Pub/Sub message.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage_AvroFormat_ added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_AvroFormat_ = src.IngestionDataSourceSettings_CloudStorage_AvroFormat_

type IngestionDataSourceSettings_CloudStorage_PubSubAvroFormat deprecated added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_PubSubAvroFormat = src.IngestionDataSourceSettings_CloudStorage_PubSubAvroFormat

Configuration for reading Cloud Storage data written via [Cloud Storage subscriptions](https://cloud.google.com/pubsub/docs/cloudstorage). The data and attributes fields of the originally exported Pub/Sub message will be restored when publishing.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage_PubsubAvroFormat added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_PubsubAvroFormat = src.IngestionDataSourceSettings_CloudStorage_PubsubAvroFormat

type IngestionDataSourceSettings_CloudStorage_State deprecated added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_State = src.IngestionDataSourceSettings_CloudStorage_State

Possible states for ingestion from Cloud Storage.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage_TextFormat deprecated added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_TextFormat = src.IngestionDataSourceSettings_CloudStorage_TextFormat

Configuration for reading Cloud Storage data in text format. Each line of text as specified by the delimiter will be set to the `data` field of a Pub/Sub message.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_CloudStorage_TextFormat_ added in v1.44.0

type IngestionDataSourceSettings_CloudStorage_TextFormat_ = src.IngestionDataSourceSettings_CloudStorage_TextFormat_

type IngestionDataSourceSettings_ConfluentCloud deprecated added in v1.46.0

type IngestionDataSourceSettings_ConfluentCloud = src.IngestionDataSourceSettings_ConfluentCloud

Ingestion settings for Confluent Cloud.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionDataSourceSettings_ConfluentCloud_ added in v1.46.0

type IngestionDataSourceSettings_ConfluentCloud_ = src.IngestionDataSourceSettings_ConfluentCloud_

type IngestionDataSourceSettings_ConfluentCloud_State deprecated added in v1.46.0

type IngestionDataSourceSettings_ConfluentCloud_State = src.IngestionDataSourceSettings_ConfluentCloud_State

Possible states for managed ingestion from Confluent Cloud.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent deprecated added in v1.45.0

type IngestionFailureEvent = src.IngestionFailureEvent

Payload of the Platform Log entry sent when a failure is encountered while ingesting.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_ApiViolationReason deprecated added in v1.45.0

type IngestionFailureEvent_ApiViolationReason = src.IngestionFailureEvent_ApiViolationReason

Specifies the reason why some data may have been left out of the desired Pub/Sub message due to the API message limits (https://cloud.google.com/pubsub/quotas#resource_limits). For example, when the number of attributes is larger than 100, the number of attributes is truncated to 100 to respect the limit on the attribute count. Other attribute limits are treated similarly. When the size of the desired message would've been larger than 10MB, the message won't be published at all, and ingestion of the subsequent messages will proceed as normal.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_AvroFailureReason deprecated added in v1.45.0

type IngestionFailureEvent_AvroFailureReason = src.IngestionFailureEvent_AvroFailureReason

Set when an Avro file is unsupported or its format is not valid. When this occurs, one or more Avro objects won't be ingested.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_AwsMskFailure added in v1.46.0

type IngestionFailureEvent_AwsMskFailure = src.IngestionFailureEvent_AwsMskFailure

type IngestionFailureEvent_AwsMskFailureReason deprecated added in v1.46.0

type IngestionFailureEvent_AwsMskFailureReason = src.IngestionFailureEvent_AwsMskFailureReason

Failure when ingesting from an Amazon MSK source.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_AwsMskFailureReason_ApiViolationReason added in v1.46.0

type IngestionFailureEvent_AwsMskFailureReason_ApiViolationReason = src.IngestionFailureEvent_AwsMskFailureReason_ApiViolationReason

type IngestionFailureEvent_AzureEventHubsFailure added in v1.46.0

type IngestionFailureEvent_AzureEventHubsFailure = src.IngestionFailureEvent_AzureEventHubsFailure

type IngestionFailureEvent_AzureEventHubsFailureReason deprecated added in v1.46.0

type IngestionFailureEvent_AzureEventHubsFailureReason = src.IngestionFailureEvent_AzureEventHubsFailureReason

Failure when ingesting from an Azure Event Hubs source.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_AzureEventHubsFailureReason_ApiViolationReason added in v1.46.0

type IngestionFailureEvent_AzureEventHubsFailureReason_ApiViolationReason = src.IngestionFailureEvent_AzureEventHubsFailureReason_ApiViolationReason

type IngestionFailureEvent_CloudStorageFailure deprecated added in v1.45.0

type IngestionFailureEvent_CloudStorageFailure = src.IngestionFailureEvent_CloudStorageFailure

Failure when ingesting from a Cloud Storage source.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_CloudStorageFailure_ added in v1.45.0

type IngestionFailureEvent_CloudStorageFailure_ = src.IngestionFailureEvent_CloudStorageFailure_

type IngestionFailureEvent_CloudStorageFailure_ApiViolationReason added in v1.45.0

type IngestionFailureEvent_CloudStorageFailure_ApiViolationReason = src.IngestionFailureEvent_CloudStorageFailure_ApiViolationReason

type IngestionFailureEvent_CloudStorageFailure_AvroFailureReason added in v1.45.0

type IngestionFailureEvent_CloudStorageFailure_AvroFailureReason = src.IngestionFailureEvent_CloudStorageFailure_AvroFailureReason

type IngestionFailureEvent_ConfluentCloudFailure added in v1.46.0

type IngestionFailureEvent_ConfluentCloudFailure = src.IngestionFailureEvent_ConfluentCloudFailure

type IngestionFailureEvent_ConfluentCloudFailureReason deprecated added in v1.46.0

type IngestionFailureEvent_ConfluentCloudFailureReason = src.IngestionFailureEvent_ConfluentCloudFailureReason

Failure when ingesting from a Confluent Cloud source.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type IngestionFailureEvent_ConfluentCloudFailureReason_ApiViolationReason added in v1.46.0

type IngestionFailureEvent_ConfluentCloudFailureReason_ApiViolationReason = src.IngestionFailureEvent_ConfluentCloudFailureReason_ApiViolationReason

type JavaScriptUDF deprecated added in v1.48.0

type JavaScriptUDF = src.JavaScriptUDF

User-defined JavaScript function that can transform or filter a Pub/Sub message.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSchemaRevisionsRequest deprecated added in v1.29.0

type ListSchemaRevisionsRequest = src.ListSchemaRevisionsRequest

Request for the `ListSchemaRevisions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSchemaRevisionsResponse deprecated added in v1.29.0

type ListSchemaRevisionsResponse = src.ListSchemaRevisionsResponse

Response for the `ListSchemaRevisions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSchemasRequest deprecated

type ListSchemasRequest = src.ListSchemasRequest

Request for the `ListSchemas` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSchemasResponse deprecated

type ListSchemasResponse = src.ListSchemasResponse

Response for the `ListSchemas` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSnapshotsRequest deprecated

type ListSnapshotsRequest = src.ListSnapshotsRequest

Request for the `ListSnapshots` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSnapshotsResponse deprecated

type ListSnapshotsResponse = src.ListSnapshotsResponse

Response for the `ListSnapshots` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSubscriptionsRequest deprecated

type ListSubscriptionsRequest = src.ListSubscriptionsRequest

Request for the `ListSubscriptions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListSubscriptionsResponse deprecated

type ListSubscriptionsResponse = src.ListSubscriptionsResponse

Response for the `ListSubscriptions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicSnapshotsRequest deprecated

type ListTopicSnapshotsRequest = src.ListTopicSnapshotsRequest

Request for the `ListTopicSnapshots` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicSnapshotsResponse deprecated

type ListTopicSnapshotsResponse = src.ListTopicSnapshotsResponse

Response for the `ListTopicSnapshots` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicSubscriptionsRequest deprecated

type ListTopicSubscriptionsRequest = src.ListTopicSubscriptionsRequest

Request for the `ListTopicSubscriptions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicSubscriptionsResponse deprecated

type ListTopicSubscriptionsResponse = src.ListTopicSubscriptionsResponse

Response for the `ListTopicSubscriptions` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicsRequest deprecated

type ListTopicsRequest = src.ListTopicsRequest

Request for the `ListTopics` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ListTopicsResponse deprecated

type ListTopicsResponse = src.ListTopicsResponse

Response for the `ListTopics` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type MessageStoragePolicy deprecated

type MessageStoragePolicy = src.MessageStoragePolicy

A policy constraining the storage of messages published to the topic.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type MessageTransform deprecated added in v1.48.0

type MessageTransform = src.MessageTransform

All supported message transforms types.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type MessageTransform_JavascriptUdf added in v1.48.0

type MessageTransform_JavascriptUdf = src.MessageTransform_JavascriptUdf

type ModifyAckDeadlineRequest deprecated

type ModifyAckDeadlineRequest = src.ModifyAckDeadlineRequest

Request for the ModifyAckDeadline method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ModifyPushConfigRequest deprecated

type ModifyPushConfigRequest = src.ModifyPushConfigRequest

Request for the ModifyPushConfig method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PlatformLogsSettings deprecated added in v1.44.0

type PlatformLogsSettings = src.PlatformLogsSettings

Settings for Platform Logs produced by Pub/Sub.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PlatformLogsSettings_Severity deprecated added in v1.44.0

type PlatformLogsSettings_Severity = src.PlatformLogsSettings_Severity

Severity levels of Platform Logs.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PublishRequest deprecated

type PublishRequest = src.PublishRequest

Request for the Publish method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PublishResponse deprecated

type PublishResponse = src.PublishResponse

Response for the `Publish` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PublisherClient deprecated

type PublisherClient = src.PublisherClient

PublisherClient is the client API for Publisher service. For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

func NewPublisherClient deprecated

func NewPublisherClient(cc grpc.ClientConnInterface) PublisherClient

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PublisherServer deprecated

type PublisherServer = src.PublisherServer

PublisherServer is the server API for Publisher service.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PubsubMessage deprecated

type PubsubMessage = src.PubsubMessage

A message that is published by publishers and consumed by subscribers. The message must contain either a non-empty data field or at least one attribute. Note that client libraries represent this object differently depending on the language. See the corresponding [client library documentation](https://cloud.google.com/pubsub/docs/reference/libraries) for more information. See [quotas and limits] (https://cloud.google.com/pubsub/quotas) for more information about message limits.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PullRequest deprecated

type PullRequest = src.PullRequest

Request for the `Pull` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PullResponse deprecated

type PullResponse = src.PullResponse

Response for the `Pull` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PushConfig deprecated

type PushConfig = src.PushConfig

Configuration for a push delivery endpoint.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PushConfig_NoWrapper deprecated added in v1.32.0

type PushConfig_NoWrapper = src.PushConfig_NoWrapper

Sets the `data` field as the HTTP body for delivery.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PushConfig_NoWrapper_ added in v1.32.0

type PushConfig_NoWrapper_ = src.PushConfig_NoWrapper_

type PushConfig_OidcToken deprecated

type PushConfig_OidcToken = src.PushConfig_OidcToken

Contains information needed for generating an [OpenID Connect token](https://developers.google.com/identity/protocols/OpenIDConnect).

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PushConfig_OidcToken_

type PushConfig_OidcToken_ = src.PushConfig_OidcToken_

type PushConfig_PubsubWrapper deprecated added in v1.32.0

type PushConfig_PubsubWrapper = src.PushConfig_PubsubWrapper

The payload to the push endpoint is in the form of the JSON representation of a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage).

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type PushConfig_PubsubWrapper_ added in v1.32.0

type PushConfig_PubsubWrapper_ = src.PushConfig_PubsubWrapper_

type ReceivedMessage deprecated

type ReceivedMessage = src.ReceivedMessage

A message and its corresponding acknowledgment ID.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type RetryPolicy deprecated

type RetryPolicy = src.RetryPolicy

A policy that specifies how Pub/Sub retries message delivery. Retry delay will be exponential based on provided minimum and maximum backoffs. https://en.wikipedia.org/wiki/Exponential_backoff. RetryPolicy will be triggered on NACKs or acknowledgement deadline exceeded events for a given message. Retry Policy is implemented on a best effort basis. At times, the delay between consecutive deliveries may not match the configuration. That is, delay can be more or less than configured backoff.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type RollbackSchemaRequest deprecated added in v1.29.0

type RollbackSchemaRequest = src.RollbackSchemaRequest

Request for the `RollbackSchema` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Schema deprecated

type Schema = src.Schema

A schema resource.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SchemaServiceClient deprecated

type SchemaServiceClient = src.SchemaServiceClient

SchemaServiceClient is the client API for SchemaService service. For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

func NewSchemaServiceClient deprecated

func NewSchemaServiceClient(cc grpc.ClientConnInterface) SchemaServiceClient

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SchemaServiceServer deprecated

type SchemaServiceServer = src.SchemaServiceServer

SchemaServiceServer is the server API for SchemaService service.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SchemaSettings deprecated

type SchemaSettings = src.SchemaSettings

Settings for validating messages published against a schema.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SchemaView deprecated

type SchemaView = src.SchemaView

View of Schema object fields to be returned by GetSchema and ListSchemas.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Schema_Type deprecated

type Schema_Type = src.Schema_Type

Possible schema definition types.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SeekRequest deprecated

type SeekRequest = src.SeekRequest

Request for the `Seek` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SeekRequest_Snapshot

type SeekRequest_Snapshot = src.SeekRequest_Snapshot

type SeekRequest_Time

type SeekRequest_Time = src.SeekRequest_Time

type SeekResponse deprecated

type SeekResponse = src.SeekResponse

Response for the `Seek` method (this response is empty).

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Snapshot deprecated

type Snapshot = src.Snapshot

A snapshot resource. Snapshots are used in [Seek](https://cloud.google.com/pubsub/docs/replay-overview) operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type StreamingPullRequest deprecated

type StreamingPullRequest = src.StreamingPullRequest

Request for the `StreamingPull` streaming RPC method. This request is used to establish the initial stream as well as to stream acknowledgements and ack deadline modifications from the client to the server.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type StreamingPullResponse deprecated

type StreamingPullResponse = src.StreamingPullResponse

Response for the `StreamingPull` method. This response is used to stream messages from the server to the client.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type StreamingPullResponse_AcknowledgeConfirmation deprecated

type StreamingPullResponse_AcknowledgeConfirmation = src.StreamingPullResponse_AcknowledgeConfirmation

Acknowledgement IDs sent in one or more previous requests to acknowledge a previously received message.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type StreamingPullResponse_ModifyAckDeadlineConfirmation deprecated

type StreamingPullResponse_ModifyAckDeadlineConfirmation = src.StreamingPullResponse_ModifyAckDeadlineConfirmation

Acknowledgement IDs sent in one or more previous requests to modify the deadline for a specific message.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type StreamingPullResponse_SubscriptionProperties deprecated

type StreamingPullResponse_SubscriptionProperties = src.StreamingPullResponse_SubscriptionProperties

Subscription properties sent as part of the response.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SubscriberClient deprecated

type SubscriberClient = src.SubscriberClient

SubscriberClient is the client API for Subscriber service. For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

func NewSubscriberClient deprecated

func NewSubscriberClient(cc grpc.ClientConnInterface) SubscriberClient

Deprecated: Please use funcs in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type SubscriberServer deprecated

type SubscriberServer = src.SubscriberServer

SubscriberServer is the server API for Subscriber service.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Subscriber_StreamingPullClient

type Subscriber_StreamingPullClient = src.Subscriber_StreamingPullClient

type Subscriber_StreamingPullServer

type Subscriber_StreamingPullServer = src.Subscriber_StreamingPullServer

type Subscription deprecated

type Subscription = src.Subscription

A subscription resource. If none of `push_config`, `bigquery_config`, or `cloud_storage_config` is set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Subscription_AnalyticsHubSubscriptionInfo deprecated added in v1.44.0

type Subscription_AnalyticsHubSubscriptionInfo = src.Subscription_AnalyticsHubSubscriptionInfo

Information about an associated [Analytics Hub subscription](https://cloud.google.com/bigquery/docs/analytics-hub-manage-subscriptions).

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Subscription_State deprecated

type Subscription_State = src.Subscription_State

Possible states for a subscription.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Topic deprecated

type Topic = src.Topic

A topic resource.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type Topic_State deprecated added in v1.36.0

type Topic_State = src.Topic_State

The state of the topic.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UnimplementedPublisherServer deprecated

type UnimplementedPublisherServer = src.UnimplementedPublisherServer

UnimplementedPublisherServer can be embedded to have forward compatible implementations.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UnimplementedSchemaServiceServer deprecated

type UnimplementedSchemaServiceServer = src.UnimplementedSchemaServiceServer

UnimplementedSchemaServiceServer can be embedded to have forward compatible implementations.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UnimplementedSubscriberServer deprecated

type UnimplementedSubscriberServer = src.UnimplementedSubscriberServer

UnimplementedSubscriberServer can be embedded to have forward compatible implementations.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UpdateSnapshotRequest deprecated

type UpdateSnapshotRequest = src.UpdateSnapshotRequest

Request for the UpdateSnapshot method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UpdateSubscriptionRequest deprecated

type UpdateSubscriptionRequest = src.UpdateSubscriptionRequest

Request for the UpdateSubscription method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type UpdateTopicRequest deprecated

type UpdateTopicRequest = src.UpdateTopicRequest

Request for the UpdateTopic method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ValidateMessageRequest deprecated

type ValidateMessageRequest = src.ValidateMessageRequest

Request for the `ValidateMessage` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ValidateMessageRequest_Name

type ValidateMessageRequest_Name = src.ValidateMessageRequest_Name

type ValidateMessageRequest_Schema

type ValidateMessageRequest_Schema = src.ValidateMessageRequest_Schema

type ValidateMessageResponse deprecated

type ValidateMessageResponse = src.ValidateMessageResponse

Response for the `ValidateMessage` method. Empty for now.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ValidateSchemaRequest deprecated

type ValidateSchemaRequest = src.ValidateSchemaRequest

Request for the `ValidateSchema` method.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

type ValidateSchemaResponse deprecated

type ValidateSchemaResponse = src.ValidateSchemaResponse

Response for the `ValidateSchema` method. Empty for now.

Deprecated: Please use types in: cloud.google.com/go/pubsub/v2/apiv1/pubsubpb

Jump to